Reg

Struct Reg 

pub struct Reg<'a> {
    pub address: Cells<'a>,
    pub size: Cells<'a>,
}
The value of a reg property.

Fields

address: Cells<'a>

The address of the device within the address space of the parent bus.

size: Cells<'a>

The size of the device within the address space of the parent bus.

Implementations

Source

impl<'a> Reg<'a>

pub fn address<T: Default + From<u32> + Shl<usize, Output = T> + BitOr<Output = T>>( self, ) -> Result<T, StandardError>

Attempts to return the address as the given type, if it will fit.

Errors

Returns StandardError::TooManyCells if the address doesn’t fit in T.

pub fn size<T: Default + From<u32> + Shl<usize, Output = T> + BitOr<Output = T>>( self, ) -> Result<T, StandardError>

Attempts to return the size as the given type, if it will fit.

Errors

Returns StandardError::TooManyCells if the size doesn’t fit in T.