#[non_exhaustive]pub enum FdtErrorKind {
InvalidMagic,
UnsupportedVersion(u32),
InvalidLength,
InvalidHeader(&'static str),
BadToken(u32),
InvalidOffset,
InvalidString,
MemReserveNotTerminated,
MemReserveInvalid,
}Expand description
The kind of an error that can occur when parsing a device tree.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidMagic
The magic number of the device tree is invalid.
UnsupportedVersion(u32)
The Device Tree version is not supported by this library.
InvalidLength
The length of the device tree is invalid.
InvalidHeader(&'static str)
The header failed validation.
BadToken(u32)
An invalid token was encountered.
InvalidOffset
A read from data at invalid offset was attempted.
InvalidString
An invalid string was encountered.
MemReserveNotTerminated
Memory reservation block has not been terminated with a null entry.
MemReserveInvalid
Memory reservation block has an entry that is unaligned or has invalid size.