pub struct Reg<'a> {
pub address: Cells<'a>,
pub size: Cells<'a>,
}Expand description
The value of a reg property.
Fields
address: Cells<'a>The address of the device within the address space of the parent bus.
size: Cells<'a>The size of the device within the address space of the parent bus.
Implementations